@@ -1,6 +1,7 @@
 "print.aov.ltm" <-
 function (x, digits = 3, ...){
-    if(!inherits(x, "aov.ltm")) stop("Use only with 'aov.ltm' objects.\n")
+    if(!inherits(x, "aov.ltm"))
+        stop("Use only with 'aov.ltm' objects.\n")
     p.val <- round(x$p.value, 3)
     p.val <- if (p.val < 0.001) "<0.001" else p.val
     dat <- data.frame(AIC = round(c(x$aic0, x$aic1), 2), BIC = round(c(x$bic0, x$bic1), 2), 
@@ -8,6 +9,7 @@ function (x, digits = 3, ...){
                 p.value = c("", p.val), row.names = c(x$nam0, x$nam1))
     cat("\n Anova Table\n")
     print(dat)
+    cat("\n")
     invisible(x)
 }
 
