@@ -1,6 +1,7 @@
 "print.aov.rasch" <-
 function(x, digits = 3, ...){
-    if(!inherits(x, "aov.rasch")) stop("Use only with 'aov.rasch' objects.\n")
+    if(!inherits(x, "aov.rasch"))
+        stop("Use only with 'aov.rasch' objects.\n")
     if (!is.null(x$LRT)) {
         p.val <- round(x$p.value, 3)
         p.val <- if(p.val < 0.001) "<0.001" else p.val
@@ -16,9 +17,10 @@ function(x, digits = 3, ...){
         cat("\nGoodness-of-Fit using Pearson chi-squared\n")
         cat("\nCall:\n", deparse(x$call), "\n\n", sep = "")
         cat("Tobs:", round(x$Tobs, 2), "\n")
-        cat("# bootstrap samples:", x$B + 1, "\n")
+        cat("# Bootstrap samples:", x$B + 1, "\n")
         cat("p-value:", p.val, "\n")
     }
+    cat("\n")
     invisible(x)
 }
 
