@@ -1,7 +1,8 @@
 "print.fscores" <-
-function (x, ...){
-    if(!inherits(x, "fscores")) stop("Use only with 'fscores' objects.\n")
-    cat("\nCall:\n", deparse(x$call), "\n", sep="")
+function(x, ...){
+    if(!inherits(x, "fscores"))
+        stop("Use only with 'fscores' objects.\n")
+    cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), "\n", sep = "")
     methodMI <- x$method == "MI"
     cat("\nScoring Method:", if (methodMI) "Multiple Imputation\n" else if (x$method == "EB") "Empirical Bayes\n" else "Component\n")
     if (methodMI) cat("# Imputations:", x$B, "\n")
@@ -9,6 +10,7 @@ function (x, ...){
     dat <- x$score.dat
     dat[] <- lapply(dat, function(x.) if (is.numeric(x.)) round(x., 3) else x.)
     print(dat)
+    cat("\n")
     invisible(x)
 }
 
